============================================
Contributing to Kwant and reporting problems
============================================

We see Kwant not just as a package with fixed functionality, but rather as a
framework for implementing different physics-related algorithms using a common
set of concepts and, if possible, a shared interface.  We have designed it
leaving room for growth, and plan to keep extending it.

External contributions to Kwant are highly welcome.  You can help to advance
the project not only by writing code, but also by reporting bugs, and
fixing/improving the documentation.  Please see the `Kwant website
<http://kwant-project.org/community>`_ for information on how to get in touch
with the Kwant community.
